#  BEEN: Benchmarking Environment
#  ==============================
#
#  File author: Jakub Lehotsky
#
#  GNU Lesser General Public License Version 2.1
#  ---------------------------------------------
#  Copyright (C) 2004-2006 Distributed Systems Research Group,
#  Faculty of Mathematics and Physics, Charles University in Prague
#
#  This library is free software; you can redistribute it and/or
#  modify it under the terms of the GNU Lesser General Public
#  License version 2.1, as published by the Free Software Foundation.
#
#  This library is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
#  Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public
#  License along with this library; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
#  MA  02111-1307  USA

# Note: these functions are documented in .hlp files, that come together with whole R package, and
#		can be browsed via BEEN UI. See BEEN web packages for more R packages to download

### Entities handling functions - analyses

base.listAnalyses <- function() {

	dirList <- list.files(base.getDatabaseRoot());
	aidList <- as.numeric(dirList);
	aidList[!is.na(aidList)];
	
}

base.getAnalysesCount <- function() {

	length(base.listAnalyses());
}
### Entities handling functions - experiments

base.listExperiments <- function(aid) {

	dirList <- list.files(paste(base.getDatabaseRoot(), "/", aid, sep = ""));
	eidList <- as.numeric(dirList);
	eidList[!is.na(eidList)];
	
}

base.getExperimentCount <- function(aid) {
	
	length(base.listExperiments(aid));
	
}

### Entities handling functions - binaries

base.listBinaries <- function(aid, eid) {

	dirList <- list.files(paste(base.getDatabaseRoot(), "/", aid, "/", eid, sep = ""));
	bidList <- as.numeric(dirList);
	bidList[!is.na(bidList)];
	
}

base.getBinariesCount <- function (aid, eid) {

	length(base.getBinariesCount(aid,eid));
	
}


########### Validity map functions
base.loadValidityMap <- function(mapFilename) {

	filename = paste(base.getDatabaseRoot(), "/", mapFilename, sep="");
	map = scan(mapFilename, what=list(integer(0), logical(0), character(0), integer(0)), sep = "\t");
	
	map;
}

base.getRunValidity <- function(rid) {

	map[[rid]][2];
	
}

base.getRunFilename <- function(aid, eid, bid, rid) {

	filename = paste(base.getDatabaseRoot(), "/", mapFilename, sep="");

	filename; 
}

base.getRunLoadInfo <- function(aid, eid, bid, rid) {
	
	map[[rid]][3];
	
}


# Function to load run data
# note - rindex is not rid! for reading by rid, please make query into binary validity map
base.loadRunData <- function(aid, eid, bid, rindex, table, host) {

	filename = paste(base.getDatabaseRoot(), "/", aid, "/", eid, "/", bid, "/", rindex, "-", 
						table, "-", host, sep="");
	
	#write(paste("loading", filename), file=stderr());
	
	ncdata <- open.nc(filename);
	values <- numeric(0);
	try(values <- var.get.nc(ncdata, variable="values"), silent = TRUE);
	close.nc(ncdata);
	
	return (values)
	
}
