#  BEEN: Benchmarking Environment
#  ==============================
#
#  File author: Jakub Lehotsky
#
#  GNU Lesser General Public License Version 2.1
#  ---------------------------------------------
#  Copyright (C) 2004-2006 Distributed Systems Research Group,
#  Faculty of Mathematics and Physics, Charles University in Prague
#
#  This library is free software; you can redistribute it and/or
#  modify it under the terms of the GNU Lesser General Public
#  License version 2.1, as published by the Free Software Foundation.
#
#  This library is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
#  Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public
#  License along with this library; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
#  MA  02111-1307  USA

# Note: these functions are documented in .hlp files, that come together with whole R package, and
#		can be browsed via BEEN UI. See BEEN web packages for more R packages to download

# This file contains set of functions to use invalidation mechanism (i.e. scripts autorunning if
# something is deleted)

base.resetAnalysisInvalidateScripts <- function (aid) {

	pathToScripts = paste(base.getDatabaseRoot(), "/", aid, "/invalidate/scripts", sep="");
	
	if (file.exists(pathToScripts)) {
		file.remove(pathToScripts);
	}

}

base.addAnalysisInvalidateScript <- function (aid, script="") {

	pathToScript = paste(base.getDatabaseRoot(), "/", aid, "/invalidate/scripts", sep="");

	cat(script, "\n", file=pathToScript, sep = "\t", append = TRUE);
			
}

base.resetExperimentInvalidateScripts <- function (aid, eid) {

	pathToScripts = paste(base.getDatabaseRoot(), "/", aid, "/", eid, "/invalidate/scripts", sep="");
	
	if (file.exists(pathToScripts)) {
		file.remove(pathToScripts);
	}

}

base.addExperimentInvalidateScript <- function (aid, eid, script="") {

	pathToScript = paste(base.getDatabaseRoot(), "/", aid, "/", eid, "/invalidate/scripts", sep="");

	cat(script, "\n", file=pathToScript, sep = "\t", append = TRUE);
			
}


base.resetBinaryInvalidateScripts <- function (aid, eid, bid) {

	pathToScripts = paste(base.getDatabaseRoot(), "/", aid, "/", eid, "/", bid, "/invalidate/scripts", sep="");
	
	if (file.exists(pathToScripts)) {
		file.remove(pathToScripts);
	}

}

base.addBinaryInvalidateScript <- function (aid, eid, bid, script="") {

	pathToScript = paste(base.getDatabaseRoot(), "/", aid, "/", eid, "/", bid, "/invalidate/scripts", sep="");

	write(paste("Writing to file: ", pathToScript, sep=""), file=stderr());

	cat(script, "\n", file=pathToScript, sep = "\t", append = TRUE);
			
}
