#  BEEN: Benchmarking Environment
#  ==============================
#
#  File author: Jakub Lehotsky
#
#  GNU Lesser General Public License Version 2.1
#  ---------------------------------------------
#  Copyright (C) 2004-2006 Distributed Systems Research Group,
#  Faculty of Mathematics and Physics, Charles University in Prague
#
#  This library is free software; you can redistribute it and/or
#  modify it under the terms of the GNU Lesser General Public
#  License version 2.1, as published by the Free Software Foundation.
#
#  This library is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
#  Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public
#  License along with this library; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
#  MA  02111-1307  USA

# Note: these functions are documented in .hlp files, that come together with whole R package, and
#		can be browsed via BEEN UI. See BEEN web packages for more R packages to download

### Load handling and load graphs generating functions

isLoadForRun <- function (aid, eid, bid, rid) {

	loadDir <- paste(base.getDatabaseRoot(), "/", aid, "/", eid, "/", bid, "/load/", rid, sep="");
	
	file.exists(loadDir) && file.info(loadDir)[["isdir"]];
}

isGraphLoadForRun <- function (aid, eid, bid, rid) {

	loadDir <- paste(base.getDatabaseRoot(), "/", aid, "/", eid, "/", bid,
		 "/load/", rid, "/load.graphs", sep="");
	
	file.exists(loadDir);

}

test <- function() {
	testload(0,0,0,0);
}

load.generateMemoryGraph <- function (graphsListFilename, graphNumber, graphDirectory, graphFilename,
	 values, maxMem, graphTitle = "", vertLabel = "", horLabel = "", color = "black") {

		cat(c(graphNumber, graphTitle, 550, 100, graphFilename, "\n"), 
			file=graphsListFilename, sep = "\t", append = TRUE);

		fname <- paste(graphDirectory, "/", graphFilename, sep="");
		
		if (file.exists(graphFilename)) {
			file.remove(graphFilename);	
		}
		
		png(fname, width=550, height=100);
		par(mar = c(2, 4, 0, 0) + 0.2);
	
		plot(values / (1024 * 1024), type="l", pch=20, xlab = vertLabel, 
			ylab=horLabel, axes=FALSE, col = color);
			#ylim=c(0, maxMem)
		axis(1, 1:length(values));
		axis(2, las=1);
		box();

		dev.off();
}

load.generateCpuGraph <- function (graphsListFilename, graphNumber, graphDirectory, graphFilename,
	 values, graphTitle = "", vertLabel = "", horLabel = "", color = "black") {

		cat(c(graphNumber, graphTitle, 550, 100, graphFilename, "\n"), 
			file=graphsListFilename, sep = "\t", append = TRUE);

		fname <- paste(graphDirectory, "/", graphFilename, sep="");
		
		if (file.exists(graphFilename)) {
			file.remove(graphFilename);	
		}
		
		png(fname, width=550, height=100);
		par(mar = c(2, 4, 0, 0) + 0.2);

		write(dim(values)[2], file=stderr());		

		par("tmag = 0");

		for (i in 1:dim(values)[2]) {
		
			write(values[2,i], file=stderr());
			
			if (i == 1) {
				plot(values[,i], type="l", pch=20, xlab = vertLabel, 
				ylab=horLabel, axes=FALSE, col = sample(colors())[1], ylim=c(0, 100));
			} else {
				lines(values[,i], type="l", pch=20, xlab = vertLabel, 
				ylab=horLabel, axes=FALSE, col = sample(colors())[1], ylim=c(0, 100));
			}
		}

		axis(1, 1:length(values));
		axis(2, las=1);
		box();

		dev.off();
}


load.generateNetGraph <- function (graphsListFilename, graphNumber, graphDirectory, graphFilename,
	 values1, values2, graphTitle = "", vertLabel = "", horLabel = "") {

		cat(c(graphNumber, graphTitle, 550, 100, graphFilename, "\n"), 
			file=graphsListFilename, sep = "\t", append = TRUE);

		fname <- paste(graphDirectory, "/", graphFilename, sep="");
		
		if (file.exists(graphFilename)) {
			file.remove(graphFilename);	
		}
		
		png(fname, width=550, height=100);
		par(mar = c(2, 4, 0, 0) + 0.2);
	
		x <- range(c(values1, values2)) / 1024;
	
		plot(values1 / (1024), type="l", pch=20, xlab = vertLabel, 
			ylab=horLabel, ylim = c(x[1], x[2]), axes=FALSE, col = "blue");
			
		lines(values2 / (1024), type="l", pch=20, xlab = vertLabel, 
			ylab=horLabel, axes=FALSE, col = "red");
			

		axis(1, 1:length(values1));
		axis(2, las=1);
		box();

		dev.off();
}


load.generateDiskGraph <- function (graphsListFilename, graphNumber, graphDirectory, graphFilename,
	 values1, values2, graphTitle = "", vertLabel = "", horLabel = "") {

		cat(c(graphNumber, graphTitle, 550, 100, graphFilename, "\n"), 
			file=graphsListFilename, sep = "\t", append = TRUE);

		fname <- paste(graphDirectory, "/", graphFilename, sep="");
		
		if (file.exists(graphFilename)) {
			file.remove(graphFilename);	
		}
		
		png(fname, width=550, height=100);
		par(mar = c(2, 4, 0, 0) + 0.2);
	
		x <- range(c(values1, values2)) / 1024;
		
		write(x[1], file=stderr());
		write(x[2], file=stderr());
	
		plot(values1 / (1024), type="l", pch=20, xlab = vertLabel, 
			ylab=horLabel, ylim = c(x[1], x[2]), axes=FALSE, col = "blue");
			
		lines(values2 / (1024), type="l", pch=20, xlab = vertLabel, 
			ylab=horLabel, axes=FALSE, col = "red");
			

		axis(1, 1:length(values1));
		axis(2, las=1);
		box();

		dev.off();
}




testload <- function (aid, eid, bid, rid) {

	graphCounter <- 0;

	loadDir <- paste(base.getDatabaseRoot(), "/", aid, "/", eid, "/", bid,
		 "/load/", rid, sep="");
			 
	for (host in dir(loadDir))  {
	
		if (file.info(paste(loadDir, "/", host,sep=""))[["isdir"]]) {
	
			# MEMORY
	
			memoryFile <- paste(loadDir, "/", host, "/memory", sep="");
		
			m = read.table(file = memoryFile);
	
			load.generateMemoryGraph(paste(loadDir , "/", "load.graphs",sep=""), graphCounter,			
				loadDir, paste("graph", graphCounter, ".png", sep=""),
				m[["V1"]], 512, graphTitle = paste(host, " - Memory free", ""), horLabel = "MB free");
		
			graphCounter <- (graphCounter + 1);
			
			# CPU
			
			cpuFile <- paste(loadDir, "/", host, "/processor", sep="");
			
			m = read.table(file = cpuFile);
			
			if (dim(m)[2] == 1) {
				cpuTitle <- paste(host, "- Processor load");
			} else {
				cpuTitle <- paste(host, "- Processors load");
			}
			
			load.generateCpuGraph(paste(loadDir , "/", "load.graphs",sep=""), graphCounter,			
				loadDir, paste("graph", graphCounter, ".png", sep=""),
				m, graphTitle = cpuTitle, horLabel = "%");
				
			graphCounter <- (graphCounter + 1);
			
			netnamesFile <- paste(loadDir, "/", host, "/netnames", sep="");			
			netFile <- paste(loadDir, "/", host, "/net", sep="");						
			
			names = read.table(file = netnamesFile);
			
			m = read.table(file = netFile);
			
			for (i in 1:dim(names)[1]) {
			
				netTitle <- paste(host, "- Network", names[i,1], "read/write");
			
				load.generateNetGraph(paste(loadDir , "/", "load.graphs",sep=""), graphCounter,			
					loadDir, paste("graph", graphCounter, ".png", sep=""),
					m[,i*2-1], m[,i*2], graphTitle = netTitle, horLabel = "KB/s");
					
				graphCounter <- (graphCounter + 1);					
			}
			
			disknamesFile <- paste(loadDir, "/", host, "/disknames", sep="");			
			diskFile <- paste(loadDir, "/", host, "/disk", sep="");						
			
			names = read.table(file = disknamesFile);
			
			m = read.table(file = diskFile);
			
			for (i in 1:dim(names)[1]) {
			
				diskTitle <- paste(host, "- Drive", names[i,1], "access");
			
				load.generateDiskGraph(paste(loadDir , "/", "load.graphs",sep=""), graphCounter,			
					loadDir, paste("graph", graphCounter, ".png", sep=""),
					m[,i*2-1], m[,i*2], graphTitle = diskTitle, horLabel = "KB/s");
					
				graphCounter <- (graphCounter + 1);					
			}
						
		}
				
	}

}

load.generateGraphs <- function(aid, eid, bid, rid) {
	testload(aid, eid, bid, rid);
}

listLoadHosts <- function (aid, eid, bid, rid) {

	loadDir <- paste(base.getDatabaseRoot(), "/", aid, "/", eid, "/", bid,
		 "/load/", rid, sep="");
	
	dir(loadDir);

}