#  BEEN: Benchmarking Environment
#  ==============================
#
#  File author: Jakub Lehotsky
#
#  GNU Lesser General Public License Version 2.1
#  ---------------------------------------------
#  Copyright (C) 2004-2006 Distributed Systems Research Group,
#  Faculty of Mathematics and Physics, Charles University in Prague
#
#  This library is free software; you can redistribute it and/or
#  modify it under the terms of the GNU Lesser General Public
#  License version 2.1, as published by the Free Software Foundation.
#
#  This library is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
#  Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public
#  License along with this library; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
#  MA  02111-1307  USA

# Note: these functions are documented in .hlp files, that come together with whole R package, and
#		can be browsed via BEEN UI. See BEEN web packages for more R packages to download

### Metadata handling functions

## Loads and returns metadata file (i.e. key - value per line, separated with tab
## metadataFilename should be relative path in database
## returns hashmap with metadata
base.loadMetadataFile <- function(metadataFilename) {

	filename = paste(base.getDatabaseRoot(), "/", metadataFilename, sep="");
	#write(filename, file=stdout());
	a = scan(metadataFilename, what=list(character(0), character(0)), sep ="\t");

	meta <- list();
	
	# creates hashmap containg (name, value) pairs
	for (i in 1:length(a[[1]])) {
			meta[a[[1]][i]] <- a[[2]][i]; 	
	}

	meta;
}

## Returns one metadata value (file is reloaded)
base.getMetadataValue <- function(metadataFilename, key) {

	meta <- base.loadMetadataFile(metadataFilename);
	
	meta[[key]];
}

## Loads and returns hashtable with metadata of a given analysis
base.loadAnalysisMetadata <- function(aid) {

	metafile <- paste(base.getDatabaseRoot(), "/", aid, "/analysis.meta",sep="");
	meta <- base.loadMetadataFile(metafile);
	
	meta;
}

## Loads and returns hashtable with metadata of a given analysis
base.loadExperimentMetadata <- function(aid, eid) {

	metafile <- paste(base.getDatabaseRoot(), "/", aid, "/", eid ,"/experiment.meta",sep="");
	meta <- base.loadMetadataFile(metafile);
	
	meta;
}

## Loads and returns hashtable with metadata of a given analysis
base.loadBinaryMetadata <- function(aid, eid, bid) {

	metafile <- paste(base.getDatabaseRoot(), "/", aid, "/", eid , "/", bid, "/binary.meta",sep="");
	meta <- base.loadMetadataFile(metafile);
	
	meta;
}

## Returns analysis metadata value (all table is reloaded)
base.getAnalysisMetadataValue <- function(aid, key) {

	meta <- base.loadAnalysisMetadata(aid);
	meta[[key]];
}

## Returns experiment metadata value (all table is reloaded)
base.getExperimentMetadataValue <- function(aid, eid, key) {

	meta <- base.loadExperimentMetadata(aid, eid);
	meta[[key]];
}

## Returns binary metadata value (all table is reloaded)
base.getBinaryMetadataValue <- function(aid, eid, bid, key) {

	meta <- base.loadBinaryMetadata(aid, eid, bid);
	meta[[key]];
}


########## Analysis metadata functions

base.isRegressionAnalysis <- function(aid) {

	write(base.getAnalysisMetadataValue(aid, "type"), file=stderr());
    return(base.getAnalysisMetadataValue(aid, "type") == "regression");
    
}

## Returns experiment count
base.getExperimentsCount <- function(aid) {

	return(as.numeric(base.getAnalysisMetadataValue(aid, "experiments")));
	
}

## Returns complete experiment count
base.getCompleteExperimentsCount <- function(aid) {

	return(as.numeric(base.getAnalysisMetadataValue(aid, "complete experiments")));
	
}

## Returns complete experiment count
base.getValidExperimentsCount <- function(aid) {

	return(as.numeric(base.getAnalysisMetadataValue(aid, "valid experiments")));
	
}


########### Experiment binary metadata functions

base.getExperimentName <- function(aid, eid) {
	return(base.getExperimentMetadataValue(aid, eid, "name"));
}

base.getBinariesCount <- function(aid, eid) {
	return(as.numeric(base.getExperimentMetadataValue(aid, eid, "binaries")));
}

base.getCompleteBinariesCount <- function(aid, eid) {
	return(as.numeric(base.getExperimentMetadataValue(aid, eid, "complete binaries")));
}

base.getValidBinariesCount <- function(aid, eid) {
	return(as.numeric(base.getExperimentMetadataValue(aid, eid, "valid binaries")));
}

base.getExpectedBinariesCount <- function(aid, eid) {
	return(as.numeric(base.getExperimentMetadataValue(aid, eid, "expected binaries")));
}



########### Binary binary metadata functions

base.getRunsCount <- function(aid, eid, bid) {
	return(as.numeric(base.getBinaryMetadataValue(aid, eid, bid, "runs")));
}

base.getValidRunsCount <- function(aid, eid, bid) {
	return(as.numeric(base.getBinaryMetadataValue(aid, eid, bid, "valid runs")));
}

base.getExpectedRunsCount <- function(aid, eid, bid) {
	return(as.numeric(base.getBinaryMetadataValue(aid, eid, bid, "expected runs")));
}

