#  BEEN: Benchmarking Environment
#  ==============================
#
#  File author: Jakub Lehotsky
#
#  GNU Lesser General Public License Version 2.1
#  ---------------------------------------------
#  Copyright (C) 2004-2006 Distributed Systems Research Group,
#  Faculty of Mathematics and Physics, Charles University in Prague
#
#  This library is free software; you can redistribute it and/or
#  modify it under the terms of the GNU Lesser General Public
#  License version 2.1, as published by the Free Software Foundation.
#
#  This library is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
#  Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public
#  License along with this library; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
#  MA  02111-1307  USA

# Note: these functions are documented in .hlp files, that come together with whole R package, and
#		can be browsed via BEEN UI. See BEEN web packages for more R packages to download

# Statistics counting for Xampler

xampler.generateRunsStatistics <- function(aid, eid, bid, valid = TRUE) {

	# we will ignore the valid parameter - it just denotes the validity of run, which
	# envoked function call

	write("Called generateRunsStatistics()...", file=stderr());

	data <- base.loadRunData(aid, eid, bid, 0, 0, 0);
	
	columnCount = dim(data)[1];
	
	if (is.na(dim(data)[2])) {
	  columnCount = 1;
    }
	
	write(columnCount, file=stderr());
	
	for (j in (1:columnCount)-1) {	
		m <- matrix(nrow = base.getValidRunsCount(aid, eid, bid), ncol = 5);
		runCount <- base.getValidRunsCount(aid,eid,bid)-1;
		hostCount <- base.getHostCount(aid, eid);
		for (host in 0:(hostCount-1)) {
			for (i in 0:runCount) {
					data <- base.loadRunData(aid, eid, bid, i, 0, 0);
					
					if (columnCount == 1) {
						dataVector <- data[j+1];
					} else {
						dataVector <- data[j+1,];
					}
					
					m[i+1,1] <- mean(dataVector[dataVector!=-1]);
					m[i+1,2] <- var(dataVector[dataVector!=-1]);
					m[i+1,3] <- quantile(dataVector[dataVector!=-1], 0.25);
					m[i+1,4] <- median(dataVector[dataVector!=-1]);
					m[i+1,5] <- quantile(dataVector[dataVector!=-1], 0.75);		
					
			}
			statsFile <- paste(base.getDatabaseRoot(), "/", aid, "/", eid, "/", bid, "/statistics", j, "-", host, ".table", sep="");
			
			if (file.exists(statsFile)) {
				file.remove(statsFile);
			}
			
			write(statsFile, file=stderr());
			write(t(m), ncol=5, file=statsFile);
		
		}
		
	}
	
}


xampler.generateBinaryStatistics <- function(aid, eid, bid, valid = TRUE) {

	write("Called generateBinaryStatistics()...", file=stderr());
	data <- base.loadRunData(aid, eid, bid, 0, 0, 0);
	
	columnCount = dim(data)[1];
	
	hostCount <- base.getHostCount(aid, eid);
	
	if (is.na(dim(data)[2])) {
	  columnCount = 1;
    }
		
	statsTableFile <- paste(base.getDatabaseRoot(), "/", aid, "/", eid, "/", bid, 
			"/statistics.tables", sep="");

	if (file.exists(statsTableFile)) {
		file.remove(statsTableFile);
	}

	for (column in (1:columnCount)-1) {
		
		for (host in (1:hostCount)-1) {
			tablesMat <- vector();
			tablesMat[1] = column;
			tablesMat[2] = paste("binary-table", column, "-", host, sep="");
										
			cat(tablesMat, "\n", file=statsTableFile, sep = "\t", append = TRUE);
	
			dimsMat <- vector();
			dimsMat[1] = 5;
			dimsMat[2] = 1;
			
			fileBase <- paste(base.getDatabaseRoot(), "/", aid, "/", eid, "/", bid, 
					"/binary-table", column, "-", host, sep="");			
	
			statFile <- paste(fileBase, ".dim", sep="");	
			if (file.exists(statFile)) {
				file.remove(statFile);
			}		
			write.table(t(dimsMat), file=statFile, col.names = FALSE, row.names = FALSE, sep="\t");
			statFile <- paste(fileBase, ".label", sep="");	
			if (file.exists(statFile)) {
				file.remove(statFile);
			}		
			
			write(paste("Xampler statistics - column ", column,
				sep=""), file=statFile, append = TRUE);			
			statFile <- paste(fileBase, ".col", sep="");	
			if (file.exists(statFile)) {
				file.remove(statFile);
			}
			write("Whole binary value", file=statFile, append = TRUE);
			statFile <- paste(fileBase, ".row", sep="");		
			if (file.exists(statFile)) {
				file.remove(statFile);
			}
			cat(c("Mean", "Variance", "Quantile 0.25", "Median", "Quantile 0.75"), file=statFile, sep = "\t");
			
			runStatsFile  <- paste(base.getDatabaseRoot(), "/", aid, "/", eid, "/", bid, 
					"/statistics", column, "-", host, ".table", sep="");
					
			m <- matrix(nrow = base.getRunsCount(aid, eid, bid), ncol = 5);
			m = read.table(file = runStatsFile)
	
			stats <- vector();
			stats[1] = mean(m[,1])
			stats[2] = var(m[,1])
			stats[3] = NA
			stats[4] = NA
			stats[5] = NA
			
			statFile <- paste(fileBase, ".value", sep="");		
			if (file.exists(statFile)) {
				file.remove(statFile);
			}
			write.table(stats, file = statFile, col.names = FALSE, row.names = FALSE, append = TRUE);
		}
	}
}

xampler.generateExperimentStatistics <- function(aid, eid, valid = TRUE) {

	write("Called generateBinaryStatistics()...", file=stderr());

	bid <- base.listBinaries(aid,eid)[1];
	data <- base.loadRunData(aid, eid, bid, 0, 0, 0);
	
	columnCount = dim(data)[1];
	
	hostCount <- base.getHostCount(aid, eid);
	
	if (is.na(dim(data)[2])) {
	  columnCount = 1;
    }
		
	statsTableFile <- paste(base.getDatabaseRoot(), "/", aid, "/", eid, "/",
			"/statistics.tables", sep="");
			
	hostCount <- base.getHostCount(aid, eid);

	if (file.exists(statsTableFile)) {
		file.remove(statsTableFile);
	}

	for (column in (1:columnCount)-1) {
	
	    #write(paste("Working with column", column, sep = ""), file=stdout());
		for (host in (1:hostCount)-1) {
			tablesMat <- vector();
			tablesMat[1] = column;
			tablesMat[2] = paste("experiment-table", column, "-", host, sep="");
										
			cat(tablesMat, "\n", file=statsTableFile, sep = "\t", append = TRUE);
	
			dimsMat <- vector();
			dimsMat[1] = 5;
			dimsMat[2] = 1;
			
			fileBase <- paste(base.getDatabaseRoot(), "/", aid, "/", eid, "/",
					"/experiment-table", column, "-", host, sep="");
	
			statFile <- paste(fileBase, ".dim", sep="");	
			if (file.exists(statFile)) {
				file.remove(statFile);
			}		
			write.table(t(dimsMat), file=statFile, col.names = FALSE, row.names = FALSE, sep="\t");
			statFile <- paste(fileBase, ".label", sep="");	
			if (file.exists(statFile)) {
				file.remove(statFile);
			}		
			#TODO: fill column name here:
			write(paste("Xampler statistics - column ", column, "\"", sep=""), file=statFile, append = TRUE);
			statFile <- paste(fileBase, ".col", sep="");	
			if (file.exists(statFile)) {
				file.remove(statFile);
			}
			write("Whole binary value", file=statFile, append = TRUE);
			statFile <- paste(fileBase, ".row", sep="");		
			if (file.exists(statFile)) {
				file.remove(statFile);
			}
			cat(c("Mean", "Variance", "Quantile 0.25", "Median", "Quantile 0.75"), file=statFile, sep = "\t");
			
			first = TRUE;
			
			for (bid in base.listBinaries(aid, eid)) {
				runStatsFile  <- paste(base.getDatabaseRoot(), "/", aid, "/", eid, "/", bid,
						"/statistics", column, "-", host, ".table", sep="");
						
				if (first) {		
								
					m <- matrix(nrow = base.getRunsCount(aid, eid, bid), ncol = 5);
					m = read.table(file = runStatsFile)
					
					first = FALSE;
					
				} else {
				    m2 <- matrix(nrow = base.getRunsCount(aid, eid, bid), ncol = 5);
				    m2 = read.table(file = runStatsFile)
				    m <- cbind(m, m2);
				}
			}
					
			m <- matrix(nrow = base.getRunsCount(aid, eid, bid), ncol = 5);
			m = read.table(file = runStatsFile)			
	
			stats <- vector();
			stats[1] = mean(m[,1])
			stats[2] = var(m[,1])
			stats[3] = NA
			stats[4] = NA
			stats[5] = NA
			
			statFile <- paste(fileBase, ".value", sep="");		
			if (file.exists(statFile)) {
				file.remove(statFile);
			}
			write.table(stats, file = statFile, col.names = FALSE, row.names = FALSE, append = TRUE);
		}
	}
}

# TODO: rework for new statistics
xampler.generateAnalysisStatistics <- function(aid, eid, valid = TRUE) {
# takes unused parameter eid - required by experiment callbacks (no analysis
# callbacks exist now)

    expCount <- base.getExperimentsCount(aid)
    if (expCount < 2) {
    	return ()
    }
    	
	tablesMat <- vector();
	tablesMat[1] = "0";
	tablesMat[2] = "analysis-table1";
	
	statsFile <- paste(base.getDatabaseRoot(), "/", aid, "/statistics.tables", sep="");
	if (file.exists(statsFile)) {
		file.remove(statsFile);
	}
	cat(tablesMat, file=statsFile, sep = "\t");

	dimsMat <- vector();
	dimsMat[1] = 5;
	dimsMat[2] = 1;

	statFile <- paste(base.getDatabaseRoot(), "/", aid, "/analysis-table1.dim", sep="");	
	if (file.exists(statsFile)) {
		file.remove(statsFile);
	}
	write.table(t(dimsMat), file=statFile, col.names = FALSE, row.names = FALSE, sep="\t");
	statFile <- paste(base.getDatabaseRoot(), "/", aid, "/analysis-table1.label", sep="");	
	if (file.exists(statsFile)) {
		file.remove(statsFile);
	}
	write("Sample statistics", file=statFile, append = TRUE);
	statFile <- paste(base.getDatabaseRoot(), "/", aid, "/analysis-table1.col", sep="");	
	if (file.exists(statsFile)) {
		file.remove(statsFile);
	}
	write("Whole binary value", file=statFile, append = TRUE);
	statFile <- paste(base.getDatabaseRoot(), "/", aid, "/analysis-table1.row", sep="");		
	if (file.exists(statsFile)) {
		file.remove(statsFile);
	}
	cat(c("Mean", "Variance", "Quantile 0.25", "Median", "Quantile 0.75"), file=statFile, sep = "\t");

	a <- matrix(ncol = 5, nrow = base.getExperimentsCount(aid));
	
	for (i in 0:(base.getExperimentsCount(aid)-1)) {
		#Hard-coded for been beta version VT release, change to real database reading later!
		statsFile <- paste(base.getDatabaseRoot(), "/", aid, "/", i, "/experiment-table1.value", sep="")
		a[i+1,] = scan(statsFile);
	}
	
	stats <- vector();
	stats[1] = mean(a[,1])
	stats[2] = var(a[,1])
	stats[3] = NA
	stats[4] = NA
	stats[5] = NA
	
	statFile <- paste(base.getDatabaseRoot(), "/", aid, "/analysis-table1.value", sep="");		
	if (file.exists(statsFile)) {
		file.remove(statsFile);
	}
	
	write.table(stats, file = statFile, col.names = FALSE, row.names = FALSE, append = TRUE);
	
}
