/*
 *  BEEN: Benchmarking Environment
 *  ==============================
 *
 *  File author: Michal Tomcanyi
 *
 *  GNU Lesser General Public License Version 2.1
 *  ---------------------------------------------
 *  Copyright (C) 2004-2006 Distributed Systems Research Group,
 *  Faculty of Mathematics and Physics, Charles University in Prague
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License version 2.1, as published by the Free Software Foundation.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 *  MA  02111-1307  USA
 */
package cz.cuni.mff.been.benchmarkmanager;

import java.rmi.RemoteException;

import cz.cuni.mff.been.common.id.BID;

public class BinaryAdapter extends EntityAdapter<BID> 
									implements BinaryEntityInterface {

	
	BinaryAdapter(ExperimentMetadata experiment) throws RemoteException {
		super(experiment);
	}
	
	/* (non-Javadoc)
	 * @see cz.cuni.mff.been.benchmarkmanager.BinaryEntityInterface#getEntity(cz.cuni.mff.been.common.id.BID)
	 */
	public BinaryEntity getEntity(BID id) throws RemoteException {
		BinaryMetadata binary = getExperiment().getBinary(id);
		if (binary == null) {
			throw new IllegalArgumentException("Binary BID(" + id 
					+ ") does not exist");
		}
		
		return new BinaryEntity(getExperiment(),id);
	}

	/* (non-Javadoc)
	 * @see cz.cuni.mff.been.benchmarkmanager.BinaryEntityInterface#getEntities()
	 */
	public BinaryEntity[] getEntities() throws RemoteException {
		BID[] bids = getExperiment().getBinaryIds();
		BinaryEntity[] entities = new BinaryEntity[bids.length];
		int i=0;
		for (BID id : bids) {
			entities[i++] = new BinaryEntity(getExperiment(),id);
		}
		
		return entities;
	}

	/* (non-Javadoc)
	 * @see cz.cuni.mff.been.benchmarkmanager.BinaryEntityInterface#getSubentityInterface(cz.cuni.mff.been.common.id.BID)
	 */
	public RunAdapter getSubentityInterface(BID id) throws RemoteException {
		return new RunAdapter(getExperiment(),id);
	}

	public void deleteEntity(BID id) throws RemoteException {
		// TODO Auto-generated method stub
	}

	/* (non-Javadoc)
	 * @see cz.cuni.mff.been.benchmarkmanager.BinaryEntityInterface#getContext(cz.cuni.mff.been.common.id.BID)
	 */
	public String getContext(BID id) throws RemoteException {
		return getExperiment().getContextID();
	}

}
