/*
 *  BEEN: Benchmarking Environment
 *  ==============================
 *
 *  File author: David Majda
 *
 *  GNU Lesser General Public License Version 2.1
 *  ---------------------------------------------
 *  Copyright (C) 2004-2006 Distributed Systems Research Group,
 *  Faculty of Mathematics and Physics, Charles University in Prague
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License version 2.1, as published by the Free Software Foundation.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 *  MA  02111-1307  USA
 */
package cz.cuni.mff.been.benchmarkmanager;

import java.io.Serializable;


/**
 * Class containing information about entity (analysis, experiment, binary or
 * run). Used to exchange this information with the web interface.
 * 
 * The class is typed by identifier of the entity.
 *
 * @param <ID>	ID Type describing entity (AID, EID, BIR or RID)
 * @author David Majda
 */
public abstract class Entity<ID extends cz.cuni.mff.been.common.id.ID> 
		implements Serializable {
	
	/** Entity identifier. */
	private ID id;
	/** Entity name. */
	private String name;
	/** Entity description. */
	private String description;
	/** Plugin to which this entity belongs. */ 
	private String plugin;
	
	/**
	 * Allocates a new <code>Entity</code> object.
	 * 
	 * @param id entity identifier
	 * @param name entity name
	 * @param description entity description
	 * @param plugin plugin to which this entity belongs 
	 */
	protected Entity(ID id, String name, String description, String plugin) {
		this.id = id;
		this.name = name;
		this.description = description;
		this.plugin = plugin;
	}
	
	/** @return the entity identifier */
	public ID getId() {
		return id;
	}

	/** @return the entity name */
	public String getName() {
		return name;
	}

	/** @return the entity description */
	public String getDescription() {
		return description;
	}

	/** @return the plugin to which this entity belongs */
	public String getPlugin() {
		return plugin;
	}
	
	/** @return the entity status */
	public abstract EntityStatus getStatus();
}
