/*
 *  BEEN: Benchmarking Environment
 *  ==============================
 *
 *  File author: Michal Tomcanyi
 *
 *  GNU Lesser General Public License Version 2.1
 *  ---------------------------------------------
 *  Copyright (C) 2004-2006 Distributed Systems Research Group,
 *  Faculty of Mathematics and Physics, Charles University in Prague
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License version 2.1, as published by the Free Software Foundation.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 *  MA  02111-1307  USA
 */
package cz.cuni.mff.been.benchmarkmanager;

import java.rmi.RemoteException;
import java.rmi.server.UnicastRemoteObject;

import cz.cuni.mff.been.common.BeenUtils;
import cz.cuni.mff.been.common.id.OID;
import cz.cuni.mff.been.taskmanager.TaskDescriptor;

public abstract class EntityAdapter<T extends OID> extends UnicastRemoteObject 
												implements EntityInterface<T> {

	private transient ExperimentMetadata experiment;
	
	protected EntityAdapter(ExperimentMetadata experiment) throws RemoteException {
		super();
		this.experiment = experiment;
	}
	
	protected ExperimentMetadata getExperiment() {
		return experiment;
	}
	
	public TaskDescriptor[] getTasks(T id) throws RemoteException {
		return BeenUtils.sortTasks(experiment.getTasks(id));
	}
	
	public TaskDescriptor[] getAllTasks(T id) throws RemoteException {
		return BeenUtils.sortTasks(experiment.getAllTasks(id));
	}
	
}
