/*
 *  BEEN: Benchmarking Environment
 *  ==============================
 *
 *  File author: Michal Tomcanyi
 *
 *  GNU Lesser General Public License Version 2.1
 *  ---------------------------------------------
 *  Copyright (C) 2004-2006 Distributed Systems Research Group,
 *  Faculty of Mathematics and Physics, Charles University in Prague
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License version 2.1, as published by the Free Software Foundation.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 *  MA  02111-1307  USA
 */
package cz.cuni.mff.been.benchmarkmanager;

import java.util.ArrayList;
import java.util.List;

import cz.cuni.mff.been.benchmarkmanager.gui.Role;
import cz.cuni.mff.been.common.Pair;
import cz.cuni.mff.been.common.id.AID;
import cz.cuni.mff.been.common.id.EID;
import cz.cuni.mff.been.common.id.ID;
import cz.cuni.mff.been.resultsrepository.gui.CallbackRScripts;

public class ExperimentEntity extends Entity<EID> {

	
	private AID analysis;
	private ID pluginID;
	private int binaryCount;
	private int runCount;
	private int sampleCount;
	private EntityStatus status;
	private Role[] benchmarkRoles;
	private CallbackRScripts scripts;
	private List<Pair<String,String>> resultsMapping;
	
	public ExperimentEntity(ExperimentMetadata experiment) {
		super(experiment.getID(),experiment.getName(),experiment.getDescription(),experiment.getPluginName());
		this.analysis = experiment.getAnalysis();
		this.pluginID = experiment.getPlugin();
		this.binaryCount = experiment.getBinaryCount();
		this.runCount = experiment.getRunCount();
		this.sampleCount = experiment.getSamplesCount();
		this.status = experiment.getStatus();
		this.benchmarkRoles = createRoles(experiment.getRoles());
		this.scripts = experiment.getScripts();
		this.resultsMapping = experiment.getResultsMapping();
	}


	public AID getAnalysis() {
		return analysis;
	}
	
	public int getBinaryCount() {
		return binaryCount;
	}

	public ID getPluginID() {
		return pluginID;
	}

	public int getRunCount() {
		return runCount;
	}

	public int getSampleCount() {
		return sampleCount;
	}
	
	@Override
	public EntityStatus getStatus() {
		return status;
	}
	
	/**
	 * @return benchmarking roles
	 */
	public Role[] getBenchmarkRoles() {
		return benchmarkRoles;
	}
	
	/**
	 * @return R callback scripts for experiment
	 */
	public CallbackRScripts getScripts() {
		return scripts;
	}
	
	/**
	 * @return 1:1 benchmark-role -> host mapping information
	 */
	public List<Pair<String,String>> getResultsMapping() {
		return resultsMapping;
	}
	
	/*
	 * Extracts benchmarking roles from set of all roles in the experiment
	 */
	private static Role[] createRoles(StandardRole[] roles) {
		List<Role> result = new ArrayList<Role>(roles.length);
		for (StandardRole role : roles) {
			if (role.isBenchmarking()) {
				BenchmarkRole br = (BenchmarkRole)role;
				result.add(new Role(br,br.getUserHosts()));
			}
		}
		return (Role[]) result.toArray(new Role[result.size()]);
	}
	
}
