/*
 *  BEEN: Benchmarking Environment
 *  ==============================
 *
 *  File author: Michal Tomcanyi
 *
 *  GNU Lesser General Public License Version 2.1
 *  ---------------------------------------------
 *  Copyright (C) 2004-2006 Distributed Systems Research Group,
 *  Faculty of Mathematics and Physics, Charles University in Prague
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License version 2.1, as published by the Free Software Foundation.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 *  MA  02111-1307  USA
 */
package cz.cuni.mff.been.benchmarkmanager;

import java.rmi.RemoteException;

import cz.cuni.mff.been.common.id.BID;
import cz.cuni.mff.been.common.id.RID;

public class RunAdapter extends EntityAdapter<RID> implements RunEntityInterface {
	
	private BID binary;
	
	public RunAdapter(ExperimentMetadata experiment, BID binary) throws RemoteException {
		super(experiment);
		this.binary = binary;
	}
	
	/* (non-Javadoc)
	 * @see cz.cuni.mff.been.benchmarkmanager.RunEntityInterface#getEntity(cz.cuni.mff.been.common.id.RID)
	 */
	public RunEntity getEntity(RID id) throws RemoteException {
		if (getExperiment().getTaskSequence().contains(id) == false) {
			throw new IllegalArgumentException("Run RID(" + id + 
					") does not exists in the experiment");
		}
		
		return new RunEntity(getExperiment(),id);
	}

	/* (non-Javadoc)
	 * @see cz.cuni.mff.been.benchmarkmanager.RunEntityInterface#getEntities()
	 */
	public RunEntity[] getEntities() throws RemoteException {
		RID[] runs = getExperiment().getTaskSequence().getRuns(binary);
		RunEntity[] runEntities = new RunEntity[runs.length];
		int i=0;
		for (RID id : runs) {
			runEntities[i++] = new RunEntity(getExperiment(),id);
		}
		
		return runEntities;
	}

	public void deleteEntity(RID id) throws RemoteException {
		// TODO Auto-generated method stub
	}

	/* (non-Javadoc)
	 * @see cz.cuni.mff.been.benchmarkmanager.RunEntityInterface#getContext(cz.cuni.mff.been.common.id.RID)
	 */
	public String getContext(RID id) throws RemoteException {
		return getExperiment().getContextID();
	}
	
}
