/*
 *  BEEN: Benchmarking Environment
 *  ==============================
 *
 *  File author: Michal Tomcanyi
 *
 *  GNU Lesser General Public License Version 2.1
 *  ---------------------------------------------
 *  Copyright (C) 2004-2006 Distributed Systems Research Group,
 *  Faculty of Mathematics and Physics, Charles University in Prague
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License version 2.1, as published by the Free Software Foundation.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 *  MA  02111-1307  USA
 */
package cz.cuni.mff.been.benchmarkmanager.plugins;

import cz.cuni.mff.been.benchmarkmanager.ExperimentMetadata;
import cz.cuni.mff.been.benchmarkmanager.GeneratorException;


/**
 * Interface to task generators. Implementations should not use this class, instead
 * they should extend {@link TaskGenerator} class.
 * 
 * @author Michal Tomcanyi
 *
 */
public interface TaskGeneratorInterface  {

	/**
	 * Starts the generating procedure
	 * The method initializes generator and executes <code>generate()</code>
	 * method
	 * @throws GeneratorException when generation was unsuccessfull for any reason
	 * 		(incorrect or missing parameter, BEEN component error )
	 */
	void startGenerator() throws GeneratorException;

	/**
	 * Sets experiment metadata
	 * @param experiment Experiment metadata
	 */
	void setExperiment(ExperimentMetadata experiment);
	
	/**
	 * @return experiment metadata
	 */
	ExperimentMetadata getExperiment();
	
}
