/*
 *  BEEN: Benchmarking Environment
 *  ==============================
 *
 *  File author: Jaroslav Urban
 *
 *  GNU Lesser General Public License Version 2.1
 *  ---------------------------------------------
 *  Copyright (C) 2004-2006 Distributed Systems Research Group,
 *  Faculty of Mathematics and Physics, Charles University in Prague
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License version 2.1, as published by the Free Software Foundation.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 *  MA  02111-1307  USA
 */
package cz.cuni.mff.been.common.anttasks;

import java.io.File;

import org.apache.tools.ant.Project;

/**
 * Deletes files using Ant.
 * 
 * @author Jaroslav Urban
 */
public class Delete extends org.apache.tools.ant.taskdefs.Delete {
	/**
	 * 
	 * Allocates a new <code>Delete</code> object.
	 *
	 */
	private Delete() {
		// dummy ant project
		Project antProject = new Project();
		antProject.init();
		setProject(antProject);
		// dummy ant task name
		setTaskName("delete");
		setTaskType("delete");
		// dummy ant target
		setOwningTarget(null);
	}
	
	/**
	 * Deletes a file.
	 * 
	 * @param path path to the file.
	 * @throws AntTaskException if anything goes wrong.
	 */
	public static void deleteFile(String path) throws AntTaskException {
		Delete d = new Delete();
		
		File f = new File(path);
		d.setFile(f);
		try {
			d.execute();
		} catch (Exception e) {
			throw new AntTaskException(e);
		}
	}

	/**
	 * Deletes a directory.
	 * 
	 * @param path path to the directory.
	 * @throws AntTaskException if anything goes wrong.
	 */
	public static void deleteDirectory(String path) throws AntTaskException {
		Delete d = new Delete();
		
		File dir = new File(path);
		d.setDir(dir);
		try {
			d.execute();
		} catch (Exception e) {
			throw new AntTaskException(e);
		}
	}
}
