/*
 *  BEEN: Benchmarking Environment
 *  ==============================
 *
 *  File author: Jakub Lehotsky
 *
 *  GNU Lesser General Public License Version 2.1
 *  ---------------------------------------------
 *  Copyright (C) 2004-2006 Distributed Systems Research Group,
 *  Faculty of Mathematics and Physics, Charles University in Prague
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License version 2.1, as published by the Free Software Foundation.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 *  MA  02111-1307  USA
 */

package cz.cuni.mff.been.resultsrepository;


/**
 * Thread used for execution of R Scripts. It just reads registered R scripts and executes them
 * one by one
 * 
 * @author J.Lehotsky
 */
public class RBackgroundThread extends Thread {
		
	/**
	 * Construction of thread
	 */
	public RBackgroundThread() {
	}

	/** 
	 * Execute next script in the queue
	 */
	static void execNextScript(String scriptCall) {
	    
		RManager rManager;
		
		rManager = RManager.getInstance();
		
	    boolean rScripting = rManager.rScriptingEnabled();
	    
	    Logger.logDebug(
		    (rScripting ? "Running R function: " : "Would run R function:") 
		    + scriptCall);				

	    /* Call evaluating R function */
		try {
			if (rScripting) {
				RManager.executeRCommand("write(try(" + scriptCall.trim() + ", silent = TRUE), file=stderr())");
			}						
		} catch (Exception e) {
			Logger.logError("Exception when executing R:" 
					+ scriptCall + ", printing stackstrace.");
			e.printStackTrace();
		}
		
		RScriptsRunner.getInstance().clearActualEventRecord();

		Logger.logTrace(scriptCall + " finished.");	    
	}
	
	/**
	 * Execute next registered callback from queue
	 * 
	 * @param callbackInterface
	 * @param callbackData
	 */
	private void execNextCallback(FileUploadCallbackInterface callbackInterface, Object callbackData) {
		
		Logger.logTrace("Running callback.");

		if (callbackInterface != null) {
			callbackInterface.callbackFunction(callbackData);
		} else {
			Logger.logError("Null function scheduled");
		}
		
		RScriptsRunner.getInstance().clearActualEventRecord();

	}

	
	/**
	 * @see java.lang.Runnable#run()
	 */
	public void run() {
	    while (RScriptsRunner.getInstance().getRunBackroundThread()) {
			try {
				Logger.logTrace("Calling semahore acquire...");
			    RScriptsRunner.scriptsSemaphore.acquire();
			} catch (InterruptedException e) {
			    Logger.logError("Error acquiring semaphore - interrupted : " 
			    		+ e.getMessage() + ".");
			}
			RREvent functionToRun = RScriptsRunner.getInstance().getNextEventFromQueue();			
			if (functionToRun != null) {
				Logger.logTrace(RScriptsRunner.getInstance().getEventCount() 
						+ " more events in the queue.");
				if (functionToRun.getIsScript()) {
					execNextScript(functionToRun.getScriptToRun());
				} else {
					execNextCallback(functionToRun.getCallbackInterface(), 
							functionToRun.getCallbackData());
				}
			} else {
				Logger.logWarning("\"null\" event scheduled to execute by R.");
			}
	    }	
	}

}
