/*
 *  BEEN: Benchmarking Environment
 *  ==============================
 *
 *  File author: Jakub Lehotsky
 *
 *  GNU Lesser General Public License Version 2.1
 *  ---------------------------------------------
 *  Copyright (C) 2004-2006 Distributed Systems Research Group,
 *  Faculty of Mathematics and Physics, Charles University in Prague
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License version 2.1, as published by the Free Software Foundation.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 *  MA  02111-1307  USA
 */
package cz.cuni.mff.been.resultsrepository;

import java.io.BufferedReader;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.FilenameFilter;
import java.io.IOException;
import java.util.ArrayList;

import cz.cuni.mff.been.resultsrepository.gui.RFunctionHelp;

/**
 * Class implementing manipulation with help for R scripts
 * 
 * 
 * @author Jakub Lehotsky
 */
public final class RHelpManager {
		
	/** The single existing intance of RID Manager */	
	private static RHelpManager rhMInstance = null;
	
	/** Here, we store function helps */
	private RFunctionHelp[] functionsHelp;
	
	/**
	 * Constructor - private, void for singleton use 
	 */
	private RHelpManager() {
	}
	
	/**
	 * Return single instance of R Scripts help manager 
	 * 
	 * @return	reference single running instance of Graph manager
	 */
	public static RHelpManager getInstance() {
		if (rhMInstance == null) {
			rhMInstance = new RHelpManager();
		}
		return rhMInstance;
	}
	
	public void initialize() {		
	}

	/**
	 * Returns the functions help stored in memory
	 * 
	 * @return	The functions help
	 */
	public RFunctionHelp[] getRFunctionsHelp() {
	    return functionsHelp;
	}
	 
	/** 
	 * Loads help data from disk into memory 
	 * @throws IOException 
	 */
	public void reloadRFunctionsHelp()
		throws IOException {

	    ArrayList<RFunctionHelp> functionsHelp = new ArrayList<RFunctionHelp>();
			
	    File[] directoryList;
        
            File path = new File(Database.getInstance().getDatabasePath() + File.separator + "rscripts");
            
            directoryList = path.listFiles();
            
            for (int i = 0; i < directoryList.length; i++) {
            	Logger.logTrace("R load help: Checking package: " 
            			+ directoryList[i].getName() + ".");
            	if (directoryList[i].isDirectory()) {
            		
            		File packagePath = directoryList[i];
            		
            		FilenameFilter fileFilter = new FilenameFilter() {
            		        public boolean accept(File dir, String filename) {
            		            return dir.isDirectory() && (filename.matches(".*\\.hlp"));
            		        }
            		    };
            		
            		File[] helpFileList = packagePath.listFiles(fileFilter);
            	
            		Logger.logDebug("R load help: " + helpFileList.length 
            				+ " R files found, loading.");
            		
            		for (int j = 0; j < helpFileList.length; j++) {
            			Logger.logTrace("R load help: Getting help: " 
            					+ helpFileList[j].getAbsolutePath() + ".");

            			try {
            			    BufferedReader inf = new BufferedReader(new FileReader(helpFileList[j]));
            			    String helpText = "";
            			    String functionHeader;
            			    String name = helpFileList[j].getName().replaceAll("\\.hlp", "");            			    
            			    String helpLine;
            			    functionHeader = inf.readLine();
            			    if (functionHeader == null) {
            				throw new IOException("Unexpected end of file with help.");
            			    }
            			    while ((helpLine = inf.readLine()) != null) {
            				helpText += helpLine + "\n";
            			    }
            			    inf.close();
            			    functionsHelp.add(new RFunctionHelp(name, functionHeader, helpText));
            			
            			} catch (FileNotFoundException e) {
            			    Logger.logError("Error reading analysis R scripts settings : " 
            				    + e.getMessage());	
            			} catch (IOException e) {
            			    Logger.logError("Error reading analysis R scripts settings : " 
            				    + e.getMessage());
            			}
            		}            		
            	}
            }

            this.functionsHelp = functionsHelp.toArray(new RFunctionHelp[] {});	    
	}
}
