/*
 *  BEEN: Benchmarking Environment
 *  ==============================
 *
 *  File author: Jakub Lehotsky
 *
 *  GNU Lesser General Public License Version 2.1
 *  ---------------------------------------------
 *  Copyright (C) 2004-2006 Distributed Systems Research Group,
 *  Faculty of Mathematics and Physics, Charles University in Prague
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License version 2.1, as published by the Free Software Foundation.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 *  MA  02111-1307  USA
 */
package cz.cuni.mff.been.resultsrepository;

import java.rmi.Remote;
import java.rmi.RemoteException;

import cz.cuni.mff.been.common.id.AID;
import cz.cuni.mff.been.common.id.BID;
import cz.cuni.mff.been.common.id.EID;
import cz.cuni.mff.been.common.id.RID;

/**
 * Debugging interface for communication with debugging parts and unit testing parts of been
 * 
 * @author Jakub Lehotsky
 */

public interface ResultsRepositoryDebugInterface extends Remote {
		
	/**
	 * RMI name
	 */
	String RMI_NAME = "debug";
	
	/**
	 * Adds new function execution into the background queue of R scripts execution
	 * 
	 * @param 	aid	Analysis ID
	 * @param	eid Experiment ID
	 * @param	functionToRun	the string containing function to be executed in R
	 * @throws RemoteException
	 */
	void enqueueScriptExecution(AID aid, EID eid, String functionToRun) 
		throws RemoteException;
	
	/**
	 * Adds new function execution into the background queue of R scripts execution
	 * 
	 * @param 	aid	Analysis ID
	 * @param	eid Experiment ID
	 * @param	bid	Binary ID
	 * @param	functionToRun	the string containing function to be executed in R
	 * @throws RemoteException 
	 */
	void enqueueScriptExecution(AID aid, EID eid, BID bid, String functionToRun) 
		throws RemoteException;
	
	/**
	 * Adds new function execution into the background queue of R scripts execution
	 * 
	 * @param 	aid	Analysis ID
	 * @param	eid Experiment ID
	 * @param	bid Binary ID
	 * @param rid 
	 * @param	functionToRun	the string containing function to be executed in R
	 * @throws RemoteException 
	 */
	void enqueueScriptExecution(AID aid, EID eid, BID bid, RID rid, String functionToRun) 
		throws RemoteException;
	
	/**
	 * Causes R scripts (in working directory) to be reloaded into R 
	 * 
	 * @throws RemoteException 
	 * @throws ResultsRepositoryException 
	 */
	void resourceRScripts() 
		throws RemoteException, ResultsRepositoryException;

}
