/*
 *  BEEN: Benchmarking Environment
 *  ==============================
 *
 *  File author: Jakub Lehotsky
 *
 *  GNU Lesser General Public License Version 2.1
 *  ---------------------------------------------
 *  Copyright (C) 2004-2006 Distributed Systems Research Group,
 *  Faculty of Mathematics and Physics, Charles University in Prague
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License version 2.1, as published by the Free Software Foundation.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 *  MA  02111-1307  USA
 */
package cz.cuni.mff.been.resultsrepository.api;

public class AnalysisType {
	
	    /** Comparison analysis */
	    public static final int COMPARISON = 0; 
	    /** Regression analysis */
	    public static final int REGRESSION = 1; 
	    
	    private AnalysisType() {	    	
	    }
	    
	    /** 
	     * True if value is valid FileTransferStatus
	     * 
	     *  @param value Value to test
	     * @return validity
	     */
	    public static boolean valid(int value) {
	        return value >= 0 && value <= 1;  
	    }
	    
	    /**
	     * Returns short string (one word) describing status
	     * 
	     * @param status Integer status constant
	     * @return short status string 
	     */    
	    public static String toString(int status) {
	    	
	    	switch (status) {
	    		case COMPARISON:
	    			return new String("comparison");
	    		case REGRESSION:
	    			return new String("regression");
	    		default:
	    			return new String("invalid status");
	    	}
	    }
}
