package cz.cuni.mff.been.resultsrepository.gui;

import java.io.Serializable;

/**
 * Contain R scripts called as callbacks after various parts of the experiments
 * finish.
 * 
 * @author David Majda
 */
public class CallbackRScripts implements Serializable {
	/** R script called after a run completes. */
	private String completeRunScript;
	/** R script called after a binary completes. */
	private String completeBinaryScript;
	/** R script called after a experiment completes. */
	private String completeExperimentScript;
	/** R script called on the binary level after a run completes. */
	private String incompleteBinaryScript;
	/** R script called on the experiment level after a run completes. */
	private String incompleteExperimentScript;
	
	/** @return R script called after a run completes */
	public String getCompleteRunScript() {
		return completeRunScript;
	}
	
	/** @return R script called after a binary completes */
	public String getCompleteBinaryScript() {
		return completeBinaryScript;
	}
	
	/** @return R script called after a experiment completes */
	public String getCompleteExperimentScript() {
		return completeExperimentScript;
	}
	
	/** @return R script called on the binary level after a run completes */
	public String getIncompleteBinaryScript() {
		return incompleteBinaryScript;
	}
	
	/** @return R script called on the experiment level after a run completes */
	public String getIncompleteExperimentScript() {
		return incompleteExperimentScript;
	}

	/**
	 * Allocates a new <code>CallbackRScripts</code> object.
	 * 
	 * @param completeRunScript R script called after a run completes
	 * @param completeBinaryScript R script called after a binary completes
	 * @param completeExperimentScript R script called after a experiment
	 *         completes
	 * @param incompleteBinaryScript R script called on the binary level after a
	 *         run completes
	 * @param incompleteExperimentScript R script called on the experiment level
	 *         after a run completes
	 */
	public CallbackRScripts(String completeRunScript, String completeBinaryScript,
			String completeExperimentScript, String incompleteBinaryScript,
			String incompleteExperimentScript) {
		this.completeRunScript = completeRunScript;
		this.completeBinaryScript = completeBinaryScript;
		this.completeExperimentScript = completeExperimentScript;
		this.incompleteBinaryScript = incompleteBinaryScript;
		this.incompleteExperimentScript = incompleteExperimentScript;
	}
}
