/*
 *  BEEN: Benchmarking Environment
 *  ==============================
 *
 *  File author: David Majda
 *
 *  GNU Lesser General Public License Version 2.1
 *  ---------------------------------------------
 *  Copyright (C) 2004-2006 Distributed Systems Research Group,
 *  Faculty of Mathematics and Physics, Charles University in Prague
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License version 2.1, as published by the Free Software Foundation.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 *  MA  02111-1307  USA
 */
package cz.cuni.mff.been.resultsrepository.gui;

import java.io.Serializable;

/**
 * Class containing information about one item in the entity metadata. Used to
 * exchange this information with the web interface.  
 *
 * @author David Majda
 */
public class MetadataItem implements Serializable {
	/** Key represeting entity name. */  
	public static final String NAME_KEY    = "name";
	/** Key represeting entity comment. */  
	public static final String COMMENT_KEY = "comment";
	/** Key represeting entity validity flag. */  
	public static final String VALID_KEY = "valid";
	/** Key represeting entity completness flag. */  
	public static final String COMPLETE_KEY = "complete";

	/** Metadata key. */
	private String key;
	/** Metadata value. */
	private String value;

	/** @return the key */
	public String getKey() {
		return key;
	}

	/** @return the value */
	public String getValue() {
		return value;
	}

	/**
	 * Allocates a new <code>MetadataItem</code> object.
	 * 
	 * @param key metadata key
	 * @param value metadta value
	 */
	public MetadataItem(String key, String value) {
		this.key = key;
		this.value = value;
	}
}
