/*
 *  BEEN: Benchmarking Environment
 *  ==============================
 *
 *  File author: Michal Tomcanyi
 *
 *  GNU Lesser General Public License Version 2.1
 *  ---------------------------------------------
 *  Copyright (C) 2004-2006 Distributed Systems Research Group,
 *  Faculty of Mathematics and Physics, Charles University in Prague
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License version 2.1, as published by the Free Software Foundation.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 *  MA  02111-1307  USA
 */
package cz.cuni.mff.been.task.download;

import java.io.Serializable;
import java.nio.ByteBuffer;
import java.nio.channels.ServerSocketChannel;
import java.nio.channels.SocketChannel;
import java.nio.channels.WritableByteChannel;

class DownloadThread extends Thread implements Serializable {
	
	
	private ServerSocketChannel servSockChan;
	private WritableByteChannel outputChannel;
	Exception storedException = null;
	
	public DownloadThread(ServerSocketChannel socketChan, WritableByteChannel outputChannel) {
		this.servSockChan = socketChan;
		this.outputChannel = outputChannel;
	}
	
	@Override
	public void run() {
		try {
			SocketChannel chan = servSockChan.accept();
			chan.configureBlocking(true);
			ByteBuffer buf = ByteBuffer.allocate(1024);
			while (chan.read(buf) > 0) {
				buf.flip();
				outputChannel.write(buf);
				buf.clear();
			}
			chan.close();
		} catch (Exception e) {
			this.storedException = e;
		}
	}
	
	public Exception getStoredException() {
		return(storedException);
	}
}
