/*
 *  BEEN: Benchmarking Environment
 *  ==============================
 *
 *  File author: Michal Tomcanyi
 *
 *  GNU Lesser General Public License Version 2.1
 *  ---------------------------------------------
 *  Copyright (C) 2004-2006 Distributed Systems Research Group,
 *  Faculty of Mathematics and Physics, Charles University in Prague
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License version 2.1, as published by the Free Software Foundation.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 *  MA  02111-1307  USA
 */
package cz.cuni.mff.been.task.download;

import cz.cuni.mff.been.common.anttasks.AntTaskException;
import cz.cuni.mff.been.common.anttasks.Cvs;
import cz.cuni.mff.been.task.Job;
import cz.cuni.mff.been.task.TaskException;
import cz.cuni.mff.been.task.TaskInitializationException;

/**
 * Performs checkout from a CVS repository via a CVS client which must
 * be installed in the system.
 * 
 * @author Michal Tomcanyi
 */
public class NativeCVSDownload extends Job {
    // ----------------------- CONSTANTS -------------------------------
	/** Task package identifier */
	public static final String TASK_NAME = "native-cvs-download";
	
	/** Property for remote CVS repository */
	public static final String CVS_REPOSITORY = "repository";
	/** Property for CVS module */
	public static final String CVS_MODULE = "module";
	/** Property for CVS password */
    public static final String CVS_PASSWORD = "password";
    /** Property for CVS revision (tag/revision) */
    public static final String CVS_REVISION = "revision";
    /** Property for CVS date to checkout for */
    public static final String CVS_DATE = "date";
    /** Checkpoint that will be reached upon sucesfull completition of task */
    public static final String CHECKPOINT = "finish";
    
    
    // ------------------------ ATTRIBUTES -------------------------------
	
	/**
	 * Allocates a new <code>NativeCVSDownload</code> object.
	 *
	 * @throws TaskInitializationException
	 */
	public NativeCVSDownload() throws TaskInitializationException {
		super();
	}
	
	private void download() throws AntTaskException {
		Cvs.checkout(getTaskProperty(CVS_REPOSITORY),
				getTaskProperty(CVS_PASSWORD),
				null,
				getTaskProperty(CVS_MODULE),
				getTaskProperty(CVS_REVISION),
				getTaskProperty(CVS_DATE),
				getWorkingDirectory());
	}
	
	@Override
	protected void run() throws TaskException {
		
		try {
			download();
		} catch (AntTaskException e) {
			e.printStackTrace();
			logFatal("Checkout command aborted: " + e.getMessage());
			throw new TaskException("Checkout command aborted",e);
		}
	}
	
	@Override
	protected void checkRequiredProperties() throws TaskException {
		checkRequiredProperties(new String[]{CVS_MODULE,CVS_REPOSITORY});
	}
}

