/*
 *  BEEN: Benchmarking Environment
 *  ==============================
 *
 *  File author: Jakub Lehotsky
 *
 *  GNU Lesser General Public License Version 2.1
 *  ---------------------------------------------
 *  Copyright (C) 2004-2006 Distributed Systems Research Group,
 *  Faculty of Mathematics and Physics, Charles University in Prague
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License version 2.1, as published by the Free Software Foundation.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 *  MA  02111-1307  USA
 */
package cz.cuni.mff.been.task.results.log;

import java.rmi.RemoteException;

import cz.cuni.mff.been.common.id.AID;
import cz.cuni.mff.been.common.id.EID;
import cz.cuni.mff.been.resultsrepository.ResultsRepositoryException;
import cz.cuni.mff.been.resultsrepository.ResultsRepositoryInterface;
import cz.cuni.mff.been.resultsrepository.ResultsRepositoryService;
import cz.cuni.mff.been.task.Job;
import cz.cuni.mff.been.task.TaskException;
import cz.cuni.mff.been.task.TaskInitializationException;

/**
 * This task uploads the rest of logs (i.e. all logs from tasks that were selected for log upload,
 * but were still not uploaded) 
 * 
 * @author superman
 *
 */
public class LogUploadTask extends Job {

	/** Key of command-line value */
	public static final String AID_PROPERTY = "analysis.id";
	
	/** Key of command-line value */
	public static final String EID_PROPERTY = "experiment.id";
	
	/** Task name */
	public static final String TASK_NAME = "log-collect";	
	
	/** Instance of results repository */
	private ResultsRepositoryInterface resultsRepositoryInstance;
	
	/** Analysis ID */
	private AID aid;
	
	/** Experiment ID */
	private EID eid;
	
	public LogUploadTask() throws TaskInitializationException {
		super();
	}
		
	protected void run() throws TaskException {
		
		aid = new AID(new Integer(getTaskProperty(AID_PROPERTY))); 
		eid = new EID(new Integer(getTaskProperty(EID_PROPERTY)));		
		
		try {
			resultsRepositoryInstance = (ResultsRepositoryInterface) getTasksPort().serviceFind(
					ResultsRepositoryService.SERVICE_NAME, ResultsRepositoryInterface.RMI_NAME);
		} catch (RemoteException e) {
			throw new TaskException("Couldn't connect to Results Repository", e);
		}
		
		logInfo("Initializing final logs upload into Results repository");
		try {
			resultsRepositoryInstance.finishLogUpload(aid, eid);
		} catch (ResultsRepositoryException e) {
			throw new TaskException("Results Repository error while uploading logs", e);
		} catch (RemoteException e) {
			throw new TaskException("Couldn't connect to Results Repository", e);
		}
	}
	
	@Override
	protected void checkRequiredProperties() throws TaskException {
		checkRequiredProperties(new String[]{AID_PROPERTY, EID_PROPERTY});
	}
}
