/*
 *  BEEN: Benchmarking Environment
 *  ==============================
 *
 *  File author: Jaroslav Urban
 *
 *  GNU Lesser General Public License Version 2.1
 *  ---------------------------------------------
 *  Copyright (C) 2004-2006 Distributed Systems Research Group,
 *  Faculty of Mathematics and Physics, Charles University in Prague
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License version 2.1, as published by the Free Software Foundation.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 *  MA  02111-1307  USA
 */
package cz.cuni.mff.been.task.upload.localupload;

import java.io.Serializable;
import java.nio.ByteBuffer;
import java.nio.channels.ReadableByteChannel;
import java.nio.channels.ServerSocketChannel;
import java.nio.channels.SocketChannel;

/**
 * Thread that uploads data from an input channel to a socket channel
 * @author Jaroslav Urban
 */
public class UploadThread extends Thread implements Serializable {
	private ServerSocketChannel socketChan;
	private ReadableByteChannel inputChan;
	private Exception storedException;
	
	/**
	 * Allocates a new UploadThread
	 * 
	 * @param socketChan channel for uploading
	 * @param inputChan input channel
	 */
	public UploadThread(ServerSocketChannel socketChan, ReadableByteChannel inputChan) {
		this.socketChan = socketChan;
		this.inputChan = inputChan;
	}

	/**
	 * Runs the thread.
	 */
	@Override
	public void run() {
		try {
			SocketChannel chan = socketChan.accept();
			chan.configureBlocking(true);
			ByteBuffer buf = ByteBuffer.allocate(1024);
			while (inputChan.read(buf) != -1) {
				buf.flip();
				chan.write(buf);
				buf.clear();
			}
			chan.close();
			inputChan.close();
		} catch (Exception e) {
			e.printStackTrace();
			storedException = e;
		}
	}

	/**
	 * @return Returns the storedException.
	 */
	public Exception getStoredException() {
		return storedException;
	}
}
