package cz.cuni.mff.been.taskmanager;

import java.rmi.Remote;
import java.rmi.RemoteException;

/**
 * Callback interface used when listening for events in the Task Manager
 * (currently only registering/unregistering of the Host Runtime). Those
 * who are interested in the events the must register using
 * <code>TaskManagerInterface.registerEventListener</code> method and later
 * unregister using <code>TaskManagerInterface.unregisterEventListener</code>. 
 * 
 * @author David Majda
 */
public interface HostRuntimeRegistrationListener extends Remote {
	/**
	 * Called when new Host Runtime is registered at the Task Manager.
	 * 
	 * @param hostname host where the new Host Runtime is running 
	 * @throws RemoteException if something failed during the execution of
	 *          the remote method call.
	 */
	void hostRuntimeRegistered(String hostname) throws RemoteException;

	/**
	 * Called when existing Host Runtime is unregistered at the Task Manager.
	 * 
	 * @param hostname host where the Host Runtime is running 
	 * @throws RemoteException if something failed during the execution of
	 *          the remote method call.
	 */
	void hostRuntimeUnregistered(String hostname) throws RemoteException;
}
